<?php


namespace Schaffen\Core\Form\Repositories;


use Exception;
use Freelabois\LaravelQuickstart\Extendables\Repository;
use Schaffen\Core\Form\Models\Form;

class FormRepository extends Repository
{
    protected $model = Form::class;

    protected $searchableFields = [
        ["field" => "form_status"],
        [
            "field" => "form_nome",
            'operator' => "ilike"
        ],
    ];

    public function injectFiltersOnQuery()
    {
        $foa_formeavel_tipo = null;
        $foa_formeavel_codigo = null;
        $forms_in = null;
        $has_fields = null;

        extract($this->filters);

        $this->query->when($forms_in, function ($query) use ($forms_in) {
            return $query->whereIn('form_codigo', $forms_in);
        });
        $this->query->when($has_fields, function ($query) use ($has_fields) {
           if (is_bool($has_fields) ? $has_fields : $has_fields == "true") {
              return $query->whereHas("fields");
           }
        });



        if ($foa_formeavel_tipo || $foa_formeavel_codigo) {
            $this->query->whereHas('association', function ($query) use ($foa_formeavel_tipo, $foa_formeavel_codigo) {
                $query->when($foa_formeavel_tipo, function ($query) use ($foa_formeavel_tipo) {
                    return $query->where('foa_formeavel_tipo', $foa_formeavel_tipo);
                });

                $query->when($foa_formeavel_codigo, function ($query) use ($foa_formeavel_codigo) {
                    return $query->where('foa_formeavel_codigo', $foa_formeavel_codigo);
                });

            });
        }


        parent::injectFiltersOnQuery(); // TODO: Change the autogenerated stub
    }

    public function destroy(int $id): int
    {
        try {
            return parent::destroy($id);
        } catch (Exception $exception) {
            return $this->storeOrUpdate(['form_status' => 0], $id)->form_codigo;
        }
    }


}
